@@ -1,8 +1,9 @@
 #include "streamvbyte_zigzag.h"
+#include "streamvbyte_isadetection.h"
 
 static inline
-uint32_t _zigzag_encode_32 (int32_t val) {
-	return (val + val) ^ (val >> 31);
+uint32_t _zigzag_encode_32 (uint32_t val) {
+	return (val + val) ^ ((int32_t)val >> 31);
 }
 
 void zigzag_encode(const int32_t * in, uint32_t * out, size_t N) {
@@ -19,7 +20,7 @@ void zigzag_delta_encode(const int32_t * in, uint32_t * out, size_t N, int32_t p
 
 static inline
 int32_t _zigzag_decode_32 (uint32_t val) {
-	return (val >> 1) ^ -(val & 1);
+	return (val >> 1) ^ (0-(val & 1));
 }
 
 
